@@ -5,6 +5,10 @@ class BakerError(Exception):
     pass
 
 
+class TagConflictError(Exception):
+    pass
+
+
 class FileSetError(BakerError):
     def __init__(self, actual: Set[str], expected: Set[str]):
         messages = []
@@ -14,10 +18,10 @@ class FileSetError(BakerError):
             )
         if len(expected - actual) > 0:
             messages.append(
-                "Missing files: {}".format(", ".join(list(actual - expected)))
+                "Missing files: {}".format(", ".join(list(expected - actual)))
             )
         super().__init__("; ".join(messages))
 
 
 class CircularFileSetError(BakerError):
-    pass
\ No newline at end of file
+    pass
